@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 13
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20240521
+#define __GLIBCXX__ 20250605
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1182,6 +1182,9 @@ namespace __gnu_cxx
 /* Define if openat is available in <fcntl.h>. */
 #define _GLIBCXX_HAVE_OPENAT 1
 
+/* Define if O_NONBLOCK is defined in <fcntl.h> */
+#define _GLIBCXX_HAVE_O_NONBLOCK 1
+
 /* Define if poll is available in <poll.h>. */
 #define _GLIBCXX_HAVE_POLL 1
 
@@ -1368,7 +1371,7 @@ namespace __gnu_cxx
 #define _GLIBCXX_HAVE_TGMATH_H 1
 
 /* Define to 1 if you have the `timespec_get' function. */
-/* #undef _GLIBCXX_HAVE_TIMESPEC_GET */
+#define _GLIBCXX_HAVE_TIMESPEC_GET 1
 
 /* Define to 1 if the target supports thread-local storage. */
 #define _GLIBCXX_HAVE_TLS 1
